@@ -389,7 +389,7 @@ func GetDylibsThatImport(f *dyld.File, name string) (*ImportedBy, error) {
 		for _, img := range f.Images {
 			pbl, err := f.GetDylibPrebuiltLoader(img.Name)
 			if err != nil {
-				return nil, err
+				return nil, fmt.Errorf("failed to get prebuilt loader for %s: %v", filepath.Base(img.Name), err)
 			}
 			for _, dep := range pbl.Dependents {
 				if strings.EqualFold(dep.Name, image.Name) {
@@ -401,7 +401,7 @@ func GetDylibsThatImport(f *dyld.File, name string) (*ImportedBy, error) {
 		for _, img := range f.Images {
 			m, err := img.GetPartialMacho()
 			if err != nil {
-				return nil, err
+				return nil, fmt.Errorf("failed to create partial MachO for image %s: %v", filepath.Base(img.Name), err)
 			}
 			for _, imp := range m.ImportedLibraries() {
 				if strings.EqualFold(imp, image.Name) {
@@ -426,7 +426,7 @@ func GetDylibsThatImport(f *dyld.File, name string) (*ImportedBy, error) {
 				}
 			}
 		}); err != nil {
-			return nil, err
+			return nil, fmt.Errorf("failed to get prebuilt loader set: %v", err)
 		}
 	}
 
@@ -614,21 +614,11 @@ func GetStrings(f *dyld.File, pattern string) ([]String, error) {
 			if mapping, err := f.GetMappingForOffsetForUUID(uuid, match); err == nil {
 				s.Mapping = mapping.Name
 				if sc := f.GetSubCacheInfo(uuid); sc != nil {
-					s.Mapping += ", sub_cache"
-					if sc.Extention != "" {
-						s.Mapping += fmt.Sprintf(" (%s)", sc.Extention)
-					} else {
-						s.Mapping += " (primary)"
-					}
+					s.Mapping += fmt.Sprintf(", sub_cache (%s)", sc.Extention)
 				}
 			} else {
 				if sc := f.GetSubCacheInfo(uuid); sc != nil {
-					s.Mapping += "sub_cache"
-					if sc.Extention != "" {
-						s.Mapping += fmt.Sprintf(" (%s)", sc.Extention)
-					} else {
-						s.Mapping += " (primary)"
-					}
+					s.Mapping += fmt.Sprintf("sub_cache (%s)", sc.Extention)
 				}
 			}
 			if str, err := f.GetCStringAtOffsetForUUID(uuid, match); err == nil {
